@@ -1,9 +1,10 @@
+from django.conf import settings
 from sekizai.data import SekizaiDictionary
-from sekizai.settings import VARNAME
 
 def sekizai(request=None):
     """
     Simple context processor which makes sure that the SekizaiDictionary is
     available in all templates.
     """
-    return {VARNAME: SekizaiDictionary()}
\ No newline at end of file
+    varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
+    return {varname: SekizaiDictionary()}
