@@ -1,16 +1,25 @@
 # -*- coding: utf-8 -*-
 from django.conf import settings
-from django.template import TextNode, VariableNode, NodeList
+from django.template import TextNode, VariableNode, NodeList, Variable
 from django.template.loader import get_template
 from django.template.loader_tags import BlockNode, ExtendsNode
 from sekizai.templatetags.sekizai_tags import RenderBlock
 
+
+def is_variable_extend_node(node):
+    if hasattr(node, 'parent_name_expr') and node.parent_name_expr:
+        return True
+    if hasattr(node, 'parent_name') and hasattr(node.parent_name, 'filters'):
+        if node.parent_name.filters or isinstance(node.parent_name.var, Variable):
+            return True
+    return False
+
 def _extend_blocks(extend_node, blocks):
     """
     Extends the dictionary `blocks` with *new* blocks in the parent node (recursive)
     """
     # we don't support variable extensions
-    if extend_node.parent_name_expr:
+    if is_variable_extend_node(extend_node):
         return
     parent = extend_node.get_parent(None)
     # Search for new blocks
@@ -35,8 +44,8 @@ def _extend_nodelist(extend_node):
     Returns a list of namespaces found in the parent template(s) of this
     ExtendsNode
     """
-    # we don't support variable extensions
-    if extend_node.parent_name_expr:
+    # we don't support variable extensions (1.3 way)
+    if is_variable_extend_node(extend_node):
         return []
     blocks = extend_node.blocks
     _extend_blocks(extend_node, blocks)
